Loader

Struct Loader 

pub struct Loader { /* private fields */ }
The loader of configuration.

This is created by the Builder. See the module documentation for details.

Implementations

Source

impl Loader

pub fn load<C: DeserializeOwned>(&mut self) -> Result<C, AnyError>

Loads configuration according to parameters configured on the originating Builder and on the command line.

Note that it is possible to load the configuration multiple times during the lifetime of the Loader. Each time all the sources are loaded from scratch (even new files in directories are discovered), so this can be used to reflect configuration changes at runtime.