#[repr(transparent)]pub struct Hidden<T>(pub T);Expand description
A wrapper to hide a configuration field from logs.
This acts in as much transparent way as possible towards the field inside. It only replaces the
Debug and Serialize implementations with returning "******".
The idea is if the configuration contains passwords, they shouldn’t leak into the logs. Therefore, wrap them in this, eg:
use std::io::Write;
use std::str;
use spirit::utils::Hidden;
#[derive(Debug)]
struct Cfg {
username: String,
password: Hidden<String>,
}
let cfg = Cfg {
username: "me".to_owned(),
password: "secret".to_owned().into(),
};
let mut buffer: Vec<u8> = Vec::new();
write!(&mut buffer, "{:?}", cfg)?;
assert_eq!(r#"Cfg { username: "me", password: "******" }"#, str::from_utf8(&buffer)?);Tuple Fields
0: TTrait Implementations
Sourceimpl<'de, T> Deserialize<'de> for Hidden<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Hidden<T>where
T: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T: Ord> Ord for Hidden<T>
impl<T: Ord> Ord for Hidden<T>
Sourceimpl<T: PartialOrd> PartialOrd for Hidden<T>
impl<T: PartialOrd> PartialOrd for Hidden<T>
Sourceimpl<T> StructDoc for Hidden<T>where
T: StructDoc,
impl<T> StructDoc for Hidden<T>where
T: StructDoc,
Sourcefn document() -> Documentation
fn document() -> Documentation
Returns the documentation for the type. Read more
impl<T: Eq> Eq for Hidden<T>
impl<T> StructuralPartialEq for Hidden<T>